# Asynchronous Client

::: bookwyrm.AsyncBookWyrmClient
options:
members:
\- __init__
\- get_citations
\- stream_citations
\- summarize
\- stream_summarize
\- stream_process_text
\- classify
\- extract_pdf
\- stream_extract_pdf
\- close
\- __aenter__
\- __aexit__
show_root_heading: true
show_source: true
